@@ -53,7 +53,7 @@ class DeploymentManager:
         )
 
     def update_rule_target_group(self, rule_type, rule_color, new_target_group_arn):
-        targeted_rule = self.__get_rule_with_type_and_color(rule_type, rule_color)
+        targeted_rule = self.get_rule_with_type_and_color(rule_type, rule_color)
         if targeted_rule:
             return self.__modify_rule_target_group(targeted_rule, new_target_group_arn)
 
@@ -63,7 +63,7 @@ class DeploymentManager:
             Actions=[self.__build_forward_actions(target_group_arn)]
         )
 
-    def __get_rule_with_type_and_color(self, tg_type, color):
+    def get_rule_with_type_and_color(self, tg_type, color):
         expected = (tg_type.upper(), color.upper())
         for rule in self.rules:
             for action in rule['Actions']:
